import json
import requests
from urllib.parse import quote

from log_config import logger


class HttpUtils(object):
    get = 'get'
    post = 'post'
    delete = 'delete'
    put = 'put'

    @staticmethod
    def send_request(url, method, data=None, headers={'Content-type': 'application/json'}, params=None, api_session=None, encode_url=True):
        data_json = json.dumps(data)

        merged_headers = headers.copy()
        if api_session and api_session.add_auth_token:
            api_session.add_auth_token(merged_headers)

        encoded_url = url
        if encode_url:
            encoded_url = quote(url, "\./_-:")

        response = None
        if method == HttpUtils.get:
            if api_session is not None:
                response = api_session.httpSession.get(encoded_url, data=data_json, headers=merged_headers, params=params, verify=api_session.sslVerify)
            else:
                response = requests.get(encoded_url, data=data_json, headers=headers, params=params)
        elif method == HttpUtils.post:
            if api_session is not None:
                response = api_session.httpSession.post(encoded_url, data=data_json, headers=merged_headers, params=params, verify=api_session.sslVerify)
            else:
                response = requests.post(encoded_url, data=data_json, headers=headers, params=params)
        elif method == HttpUtils.delete:
            if api_session is not None:
                response = api_session.httpSession.delete(encoded_url, headers=merged_headers, params=params, verify=api_session.sslVerify)
            else:
                response = requests.delete(encoded_url, headers=headers, params=params)
        elif method == HttpUtils.put:
            if api_session is not None:
                response = api_session.httpSession.put(encoded_url, data=data_json, headers=merged_headers, params=params, verify=api_session.sslVerify)
            else:
                response = requests.put(encoded_url, data=data_json, headers=headers, params=params)

        if response is not None:
            if response.headers.get("X-Correlation-ID"):
                logger.debug("Got response %s, from  %s, correlationId=%s ", response.status_code, response.url, str(response.headers.get("X-Correlation-ID")))
            else:
                logger.debug("Got response %s, from  %s ", response.status_code, response.url)

        if method == HttpUtils.delete:
            return response.ok
        else:
            response.raise_for_status()
            try:
                return response.json()
            except ValueError:
                # response it not json
                return response.text
            except Exception as e:
                # print("Exception for " + url + "  " + method + ",  " + str(type(e)))
                if response.headers.get("X-Correlation-ID"):
                    logger.error("Error from %s , correlationId=%s, response=%s, error=%s ",response.url,
                                 str(response.headers.get("X-Correlation-ID")), response.text, str(e))
                else:
                    logger.error("Error from %s, response=%s, error=%s ", response.url, response.text, str(e))

    @staticmethod
    def new_session():
        return requests.Session()
