version: '2.4'
services:
  conduit-worker:
    image: blueprint.azurecr.io/bpcs/conduit-worker:s3.1.2_h3.2
    labels:
      com.bpcs.conduit.displayName: "Conduit Worker"
    network_mode: host
    container_name: conduit-worker-hdfs
    restart: on-failure
    mem_swappiness: 0
    environment:
      #Allocation Parameters
      - SPARK_WORKER_CORES={{ spark_worker_cores | default(4) }}
      - SPARK_WORKER_MEMORY={{ spark_worker_memory | default('7g') }}
      - SPARK_WORKER_DIR=/spark/work
      - SPARK_WORKER_OPTS=-Dspark.worker.cleanup.enabled=true -Dspark.worker.cleanup.interval=600 -Dspark.worker.cleanup.appDataTtl=86400 -Dspark.ui.proxyBase=/sparkui -Dspark.ui.reverseProxyUrl=https://{{ spark_host }}/sparkui -Dspark.ui.reverseProxy=true
      - SPARK_WORKER_WEBUI_PORT=4081
      - SPARK_PUBLIC_DNS={{ ansible_default_ipv4.address }}
      - SPARK_LOCAL_IP={{ ansible_default_ipv4.address }}
    {% if ha_mode is defined and ha_mode | lower  == 'true' %}

      - SPARK_MASTER=spark://{{ groups[ 'conduit-master' ] | product([':7077']) |  map('join') | list | join(',') }}
      - ZOOKEEPER_CONNECT_STRING={{ zookeeper_connect | default(groups[ 'zookeeper_hosts' ] | product([':2181']) |  map('join') | list | join(',')) }}
      - HA_MODE_ENABLED=true
    {% else %}

      - SPARK_MASTER=spark://{{ spark_host | default(ansible_default_ipv4.address) }}:7077
    {% endif %}

    {% if conduit_fs_type == 'hdfs'%}

      # HDFS settings
      - DFS_NAMENODE_NAME_DIR=/mnt/dfs/namenode
      - DFS_DATANODE_DATA_DIR=/mnt/dfs/datanode
      - DFS_BLOCKSIZE=512m
      - CLUSTER_NAME=conduit
    {% if ha_mode is defined and ha_mode | lower  == 'true' %}

      - CONDUIT_MASTER_HOSTS={{ groups[ 'conduit-master' ] | join(',') }}
      - CONDUIT_JOURNAL_NODES={{ groups[ 'hdfs_journal_hosts' ] | join(',') }}
      - FS_DEFAULTFS=hdfs://conduit
      - DFS_REPLICATION=2
    {% else %}

      - FS_DEFAULTFS=hdfs://{{  groups[ 'conduit-master' ][0] | default(ansible_default_ipv4.address) }}:8020
    {% endif %}

{% endif %}

    volumes:
      - /mnt/spark/work:/spark/work
      - {{ spark_local_dirs_mount | default('/mnt/spark/local_dirs') }}:/mnt/spark/local_dirs
      - {{ hdfs_datanode_mount | default('/mnt/hdfs/datanode') }}:/mnt/dfs/datanode
      - /var/log/bpcs/spark/worker:/var/log/spark
      - /var/log/bpcs/hadoop/datanode:/var/log/hadoop
      - /etc/bpcs/docker/conduit/gcs/keyfile/:/etc/bpcs/docker/bde-server/gcs/keyfile/
